<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\MAN\Services;
use Teknisa\MAN\Services\RelatorioService;

class RelGorjetaPorRestaurante extends CrudWithParameterBag  {
   
    protected  $relGorjetaPorRestaurante = 'orm00038_relGorjetaPorRestaurante';
    protected  $relatorioService;
    protected $parameterBagColumnsSelectRelGorjetaPorRes = array('NRORG', 'CDFILIAL', 'CDLOJA' ,'DTABERTUR','DATAINI', 'DATAFIN', 'DTMOVTURCAIX','TDTMOVTURCAIX','CDVENDEDOR','TCDFILIAL','TCDLOJA','TCDVENDEDOR','TDTABERTUR');
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, $relatorioService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->relatorioService = $relatorioService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        
        
        $this->dataSourceName = $this->relGorjetaPorRestaurante;
        $this->parameterBagColumns = $this->parameterBagColumnsSelectRelGorjetaPorRes;
         
        
        $conditions = $this->relatorioService->getParamsAsArray($request);
        $conditions = $this->buildParamsForRel($conditions);
        $newRequest = $this->relatorioService->createNewZeedhiFilterRequestObject($request, $this->dataSourceName, $conditions);
        
      
       
       
        parent::find($newRequest, $response);
    }
    
    public function buildParamsForRel($conditions){
        $conditions = $this->addParams($conditions,'CDFILIAL');
        $conditions = $this->addParams($conditions,'CDLOJA');
        $conditions = $this->addParams($conditions,'CDVENDEDOR');
        $conditions = $this->addParams($conditions,'DTABERTUR');
        
        $conditions = $this->buildParamsData($conditions);
        $conditions = $this->addParams($conditions,'DTMOVTURCAIX');
        
        
        if(array_key_exists('DTABERCAIX', $conditions)){
            $conditions = $this->addParams($conditions,'DTABERCAIX');
            $conditions['DTMOVTURCAIX'] = $conditions['DTABERCAIX'];
            $conditions['TDTMOVTURCAIX'] = NULL;
            unset($conditions['DTABERCAIX']);
            unset($conditions['TDTABERCAIX']);
        }
        
        
        
       
        return $conditions;
        
    }
    
    public function addParams($conditions,$param){
        
        if(!array_key_exists($param, $conditions)) {
            $conditions[$param] = '';
            $conditions['T'.$param] = 'T';
        }else{
            $conditions[$param] = implode('_', $conditions[$param]);
            $conditions['T'.$param] = '';
        }
        return $conditions;
    }
    
    public function buildParamsData($conditions){
        if(array_key_exists('DTMOVTURCAIX', $conditions)) {
            $conditions['DATAINI'] = $conditions['DTMOVTURCAIX'][0];
            $conditions['DATAFIN'] = $conditions['DTMOVTURCAIX'][1];
        }
        unset($conditions['DTMOVTURCAIX']);
        return $conditions;
    }
    
}

